@@ -54,6 +54,8 @@ Usage::
         DescribeMovingAddressesPaginator,
         DescribeNatGatewaysPaginator,
         DescribeNetworkAclsPaginator,
+        DescribeNetworkInsightsAnalysesPaginator,
+        DescribeNetworkInsightsPathsPaginator,
         DescribeNetworkInterfacePermissionsPaginator,
         DescribeNetworkInterfacesPaginator,
         DescribePrefixListsPaginator,
@@ -77,6 +79,8 @@ Usage::
         DescribeTrafficMirrorSessionsPaginator,
         DescribeTrafficMirrorTargetsPaginator,
         DescribeTransitGatewayAttachmentsPaginator,
+        DescribeTransitGatewayConnectPeersPaginator,
+        DescribeTransitGatewayConnectsPaginator,
         DescribeTransitGatewayMulticastDomainsPaginator,
         DescribeTransitGatewayPeeringAttachmentsPaginator,
         DescribeTransitGatewayRouteTablesPaginator,
@@ -220,6 +224,8 @@ Usage::
     describe_moving_addresses_paginator: DescribeMovingAddressesPaginator = client.get_paginator("describe_moving_addresses")
     describe_nat_gateways_paginator: DescribeNatGatewaysPaginator = client.get_paginator("describe_nat_gateways")
     describe_network_acls_paginator: DescribeNetworkAclsPaginator = client.get_paginator("describe_network_acls")
+    describe_network_insights_analyses_paginator: DescribeNetworkInsightsAnalysesPaginator = client.get_paginator("describe_network_insights_analyses")
+    describe_network_insights_paths_paginator: DescribeNetworkInsightsPathsPaginator = client.get_paginator("describe_network_insights_paths")
     describe_network_interface_permissions_paginator: DescribeNetworkInterfacePermissionsPaginator = client.get_paginator("describe_network_interface_permissions")
     describe_network_interfaces_paginator: DescribeNetworkInterfacesPaginator = client.get_paginator("describe_network_interfaces")
     describe_prefix_lists_paginator: DescribePrefixListsPaginator = client.get_paginator("describe_prefix_lists")
@@ -243,6 +249,8 @@ Usage::
     describe_traffic_mirror_sessions_paginator: DescribeTrafficMirrorSessionsPaginator = client.get_paginator("describe_traffic_mirror_sessions")
     describe_traffic_mirror_targets_paginator: DescribeTrafficMirrorTargetsPaginator = client.get_paginator("describe_traffic_mirror_targets")
     describe_transit_gateway_attachments_paginator: DescribeTransitGatewayAttachmentsPaginator = client.get_paginator("describe_transit_gateway_attachments")
+    describe_transit_gateway_connect_peers_paginator: DescribeTransitGatewayConnectPeersPaginator = client.get_paginator("describe_transit_gateway_connect_peers")
+    describe_transit_gateway_connects_paginator: DescribeTransitGatewayConnectsPaginator = client.get_paginator("describe_transit_gateway_connects")
     describe_transit_gateway_multicast_domains_paginator: DescribeTransitGatewayMulticastDomainsPaginator = client.get_paginator("describe_transit_gateway_multicast_domains")
     describe_transit_gateway_peering_attachments_paginator: DescribeTransitGatewayPeeringAttachmentsPaginator = client.get_paginator("describe_transit_gateway_peering_attachments")
     describe_transit_gateway_route_tables_paginator: DescribeTransitGatewayRouteTablesPaginator = client.get_paginator("describe_transit_gateway_route_tables")
@@ -317,6 +325,8 @@ from mypy_boto3_ec2.paginator import (
     DescribeMovingAddressesPaginator,
     DescribeNatGatewaysPaginator,
     DescribeNetworkAclsPaginator,
+    DescribeNetworkInsightsAnalysesPaginator,
+    DescribeNetworkInsightsPathsPaginator,
     DescribeNetworkInterfacePermissionsPaginator,
     DescribeNetworkInterfacesPaginator,
     DescribePrefixListsPaginator,
@@ -340,6 +350,8 @@ from mypy_boto3_ec2.paginator import (
     DescribeTrafficMirrorSessionsPaginator,
     DescribeTrafficMirrorTargetsPaginator,
     DescribeTransitGatewayAttachmentsPaginator,
+    DescribeTransitGatewayConnectPeersPaginator,
+    DescribeTransitGatewayConnectsPaginator,
     DescribeTransitGatewayMulticastDomainsPaginator,
     DescribeTransitGatewayPeeringAttachmentsPaginator,
     DescribeTransitGatewayRouteTablesPaginator,
@@ -460,6 +472,8 @@ __all__ = (
     "DescribeMovingAddressesPaginator",
     "DescribeNatGatewaysPaginator",
     "DescribeNetworkAclsPaginator",
+    "DescribeNetworkInsightsAnalysesPaginator",
+    "DescribeNetworkInsightsPathsPaginator",
     "DescribeNetworkInterfacePermissionsPaginator",
     "DescribeNetworkInterfacesPaginator",
     "DescribePrefixListsPaginator",
@@ -483,6 +497,8 @@ __all__ = (
     "DescribeTrafficMirrorSessionsPaginator",
     "DescribeTrafficMirrorTargetsPaginator",
     "DescribeTransitGatewayAttachmentsPaginator",
+    "DescribeTransitGatewayConnectPeersPaginator",
+    "DescribeTransitGatewayConnectsPaginator",
     "DescribeTransitGatewayMulticastDomainsPaginator",
     "DescribeTransitGatewayPeeringAttachmentsPaginator",
     "DescribeTransitGatewayRouteTablesPaginator",
